import { THETA_BLOCK_STATUS_ENUM, THETA_TRANSACTION_TYPE_ENUM } from './enum';
export interface THETA_NETWORK_INTERFACE {
    chainId: string;
    name?: string;
    rpcUrl: string;
    explorerUrl: string;
}
export interface THETA_BLOCK_INTERFACE {
    jsonrpc: '2.0';
    id: number;
    result: {
        chain_id: 'mainnet' | 'testnet';
        epoch: string;
        height: string;
        parent: string;
        transactions_hash: string;
        state_hash: string;
        timestamp: string;
        proposer: string;
        hcc: {
            Votes: Array<{
                Block: string;
                Height: number;
                Epoch: number;
                ID: string;
                Signature: string;
            }>;
            BlockHash: string;
        };
        guardian_votes: null;
        children: Array<string>;
        status: THETA_BLOCK_STATUS_ENUM;
        hash: string;
        transactions: Array<{
            raw: {
                proposer: {
                    address: string;
                    coins: {
                        thetawei: string;
                        tfuelwei: string;
                    };
                    sequence: string;
                    signature: string;
                };
                fee?: {
                    thetawei: string;
                    tfuelwei: string;
                };
                inputs?: Array<{
                    address: string;
                    coins: {
                        thetawei: string;
                        tfuelwei: string;
                    };
                    sequence: string;
                    signature: string;
                }>;
                outputs?: Array<{
                    address: string;
                    coins: {
                        thetawei: string;
                        tfuelwei: string;
                    };
                }>;
                block_height: string;
                holder?: {
                    address: string;
                    coins: {
                        thetawei: string;
                        tfuelwei: string;
                    };
                };
                source?: {
                    address: string;
                    coins: {
                        thetawei: string;
                        tfuelwei: string;
                    };
                    sequence: string;
                    signature: string;
                };
                purpose?: number;
            };
            type: THETA_TRANSACTION_TYPE_ENUM;
            hash: string;
            receipt: null;
        }>;
    };
}
export interface HTTP_PROVIDER_INTERFACE {
    getBlock(blockHeight: number): Promise<THETA_BLOCK_INTERFACE>;
    getBlock(blockHash: string): Promise<THETA_BLOCK_INTERFACE>;
}
export interface THETA_METHOD_INTERFACE {
    method: 'theta.GetAccount' | 'theta.BroadcastRawTransaction';
}
export interface THETA_VCP_INTERFACE {
    jsonrpc: '2.0';
    id: number;
    result: {
        BlockHashVcpPairs: [
            {
                BlockHash: string;
                Vcp: {
                    SortedCandidates: Array<{
                        Holder: string;
                        Stakes: Array<{
                            source: string;
                            amount: string;
                            withdrawn: boolean;
                            return_height: string;
                        }>;
                    }>;
                };
                HeightList: {
                    Heights: Array<number>;
                };
            }
        ];
    };
}
export interface THETA_GCP_INTERFACE {
    jsonrpc: string;
    id: number;
    result: {
        BlockHashGcpPairs: [
            {
                BlockHash: string;
                Gcp: {
                    SortedGuardians: Array<{
                        Holder: string;
                        Stakes: Array<{
                            source: string;
                            amount: string;
                            withdrawn: boolean;
                            return_height: string;
                        }>;
                    }>;
                };
                HeightList: {
                    Heights: Array<number>;
                };
            }
        ];
    };
}
export interface THETA_EENP_INTERFACE {
    jsonrpc: string;
    id: number;
    result: {
        BlockHashEenpPairs: [
            {
                BlockHash: string;
                EENs: Array<{
                    Holder: string;
                    Stakes: Array<{
                        source: string;
                        amount: string;
                        withdrawn: boolean;
                        return_height: string;
                    }>;
                }>;
                HeightList: {
                    Heights: Array<number>;
                };
            }
        ];
    };
}
export interface THETA_NODE_STATUS {
    jsonrpc: '2.0';
    id: 1;
    result: {
        address: string;
        chain_id: string;
        peer_id: string;
        latest_finalized_block_hash: string;
        latest_finalized_block_height: string;
        latest_finalized_block_time: string;
        latest_finalized_block_epoch: string;
        current_epoch: string;
        current_height: string;
        current_time: string;
        syncing: false;
        genesis_block_hash: '0xd8836c6cf3c3ccea0b015b4ed0f9efb0ffe6254db793a515843c9d0f68cbab65';
    };
}
export interface CMC_PRICE_INFORMATION {
    name: string;
    price: number;
    volume_24h: number;
    market_cap: number;
    total_supply: number;
    circulating_supply: number;
    last_updated: string;
}
